#' Download data on the number of seats under dispute in local elections 
#'
#' \code{seats_local()} downloads and aggregates data on the number of seats under dispute in
#' local elections in Brazil. The function returns a \code{tbl, data.frame} where each observation
#' corresponds to a municipality office dyad.
#' 
#' @note For the elections prior to 2000, some information can be incomplete.
#'
#' @param year Election year. For this function, only the years of 1996, 2000, 2004, 2008, 2012, 2016, 2020 and 2024
#' are available.
#' 
#' @param uf Federation Unit acronym (\code{character vector}).
#'
#'
#' @param encoding Data original encoding (defaults to 'Latin-1'). This can be changed to avoid errors
#' when \code{ascii = TRUE}.
#' 
#' 
#' @param temp (\code{logical}). If \code{TRUE}, keep the temporary compressed file for future use (recommended)
#'
#' @details If export is set to \code{TRUE}, the downloaded data is saved as .dta and .sav
#'  files in the current directory.
#'
#' @return \code{seats_local()} returns a \code{data.frame}.
#'
#' @import utils
#' @importFrom magrittr "%>%"
#' @export
#' @examples
#' \dontrun{
#' df <- seats_local(2000)
#' }

seats_local <- function(year, 
                        uf = "all", 
                        encoding = "latin1", 
                        temp = TRUE){
  
  .Deprecated("elections_tse", msg = "seats_local is deprecated and will no longer be supported in electionsBR 1.0.0. Please use the elections_tse function")
  
  answer <- seats(year,
                  uf,
                  encoding, 
                  temp)
  return(answer)

}

